# Revision History

## 0.1.8 (2016/10/15)
    Implement grouping optimizer (SIM and SEQ method available)
    Impementing full extensible PSO Algorithm

## 0.1.7 (2016/05/17)
	Implement Calls Stage.
	Update pylint settings.
	Add pyswarm code.
	Implement optimization of single stage.
	Implement optimizer (Class for optimize whole process sequentially.)

## 0.1.6 (2016/03/26)
	Fixing deployment configuration.

## 0.1.1 (2016/03/26)
	Implement abstract interfaces.
	Code cleaned.
	Improve CI process.
	Add Documentation.

## 0.1.0 (2016/03/06)
	Creating application prototype - configure CI process


